package o.e.r.tim.testing;

import java.net.URL;
import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.runtime.FileLocator;
import org.eclipse.core.runtime.Path;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.recommenders.stats.rcp.interfaces.IDeveloperActivityPage;
import org.eclipse.recommenders.stats.rcp.interfaces.ITreeCategory;
import org.eclipse.recommenders.stats.rcp.interfaces.ITreeItem;
import org.eclipse.recommenders.stats.rcp.interfaces.ITreeViewerExtension;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.osgi.framework.Bundle;
import org.osgi.framework.FrameworkUtil;

public class MyClass implements ITreeViewerExtension {

	private static final String FIRST_TEST_ITEM = "First Test Item";
	private static final String MY_PAGE = "My Page";
	private static Composite detailCmp;

	@Override
	public List<String> getChildItems() {
		ArrayList<String> arrayList = new ArrayList<String>();
		arrayList.add(MY_PAGE);
		arrayList.add(FIRST_TEST_ITEM);
		return arrayList;
	}

	@Override
	public ITreeCategory getCategory() {
		ITreeCategory treeCategory = new ITreeCategory() {
			private final Image categoryImage = createImage("extdoc.png");
			private String name;
			private final List<ITreeItem> items = new ArrayList<ITreeItem>();

			@Override
			public String getName() {
				return name;
			}

			@Override
			public void setName(String value) {
				name = value;
			}

			@Override
			public List<ITreeItem> getItems() {
				return items;
			}

			@Override
			public String toString() {
				return name;
			}

			@Override
			public Image getIcon() {
				return categoryImage;
			}
		};

		treeCategory.setName(MY_PAGE);
		treeCategory.getItems().add(new ITreeItem() {
			private final Image categoryImage = createImage("hooks.png");

			@Override
			public String getName() {
				return FIRST_TEST_ITEM;
			}

			@Override
			public Image getIcon() {
				return categoryImage;
			}

			@Override
			public String toString() {
				return getName();
			}
		});
		return treeCategory;
	}

	/**
	 * That's the key method for the communication with the tree viewer
	 * selection, depending on the treeviewer selection, the right composite
	 * should be returned.
	 */
	@Override
	public Composite getComposite(String item) {
		if (MY_PAGE.equals(item)) {
			return createCategoryView();
		} else if (FIRST_TEST_ITEM.equals(item)) {
			return createChildView();
		}
		return null;
	}

	private Composite createChildView() {
		Composite myCmp = createWrapperComposite(detailCmp);
		Label label = new Label(myCmp, SWT.None);
		label.setText("Yeaaaaaaa .... that rules !!!!");
		label.setLayoutData(new GridData(SWT.CENTER, SWT.CENTER, true, true));
		return myCmp;
	}

	private Composite createCategoryView() {
		Composite myCmp = createWrapperComposite(detailCmp);
		Label label = new Label(myCmp, SWT.None);
		label.setText("My Extension Point Page: Yeaaaaaaa .... that rules !!!!");
		label.setLayoutData(new GridData(SWT.CENTER, SWT.CENTER, true, true));
		return myCmp;
	}

	@Override
	public IDeveloperActivityPage getPage() {
		IDeveloperActivityPage page = new IDeveloperActivityPage() {
			@Override
			public void createContent(Composite detailParent) {
				// save here the detail Cmp for later using
				detailCmp = detailParent;
			}
		};
		return page;
	}

	private Composite createWrapperComposite(Composite detailCmp) {
		Composite newComp = new Composite(detailCmp, SWT.NONE);
		newComp.setLayout(new GridLayout());
		newComp.setLayoutData(new GridData(GridData.FILL_BOTH));
		return newComp;
	}

	public static Image createImage(String fileName) {
		Bundle bundle = FrameworkUtil.getBundle(MyClass.class);
		URL url = FileLocator.find(bundle, new Path("icons/" + fileName), null);
		ImageDescriptor image = ImageDescriptor.createFromURL(url);
		return image.createImage();
	}

}
